@@ -27,7 +27,7 @@ except ImportError:
 
 def variables():
     if current_python_version == PYTHON2:
-        return scalalib.sharedvars.__dict__['main']
+        return scalalib.sharedvars().__dict__
     elif current_python_version == PYTHON3:
         return scalascript.variables()
     elif current_python_version == PYTHON3_MAIN:
